@@ -1,6 +1,3 @@
-
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -55,7 +52,7 @@ namespace Rosegarden
 
 class MultiViewCommandHistory : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
