@@ -45,33 +45,33 @@ LircCommander::LircCommander(LircClient *lirc, RosegardenGUIApp *rgGUIApp)
 {
     m_lirc = lirc;
     m_rgGUIApp = rgGUIApp;
-    connect(m_lirc, TQT_SIGNAL(buttonPressed(char *)),
-            this, TQT_SLOT(slotExecute(char *)) );
+    connect(m_lirc, TQ_SIGNAL(buttonPressed(char *)),
+            this, TQ_SLOT(slotExecute(char *)) );
 
-    connect(this, TQT_SIGNAL(play()),
-            m_rgGUIApp, TQT_SLOT(slotPlay()) );
-    connect(this, TQT_SIGNAL(stop()),
-            m_rgGUIApp, TQT_SLOT(slotStop()) );
-    connect(this, TQT_SIGNAL(record()),
-            m_rgGUIApp, TQT_SLOT(slotRecord()) );
-    connect(this, TQT_SIGNAL(rewind()),
-            m_rgGUIApp, TQT_SLOT(slotRewind()) );
-    connect(this, TQT_SIGNAL(rewindToBeginning()),
-            m_rgGUIApp, TQT_SLOT(slotRewindToBeginning()) );
-    connect(this, TQT_SIGNAL(fastForward()),
-            m_rgGUIApp, TQT_SLOT(slotFastforward()) );
-    connect(this, TQT_SIGNAL(fastForwardToEnd()),
-            m_rgGUIApp, TQT_SLOT(slotFastForwardToEnd()) );
-    connect(this, TQT_SIGNAL(toggleRecord()),
-            m_rgGUIApp, TQT_SLOT(slotToggleRecord()) );
-    connect(this, TQT_SIGNAL(trackDown()),
-            m_rgGUIApp, TQT_SLOT(slotTrackDown()) );
-    connect(this, TQT_SIGNAL(trackUp()),
-            m_rgGUIApp, TQT_SLOT(slotTrackUp()) );
-    connect(this, TQT_SIGNAL(trackMute()),
-            m_rgGUIApp, TQT_SLOT(slotToggleMutedCurrentTrack()) );
-    connect(this, TQT_SIGNAL(trackRecord()),
-            m_rgGUIApp, TQT_SLOT(slotToggleRecordCurrentTrack()) );
+    connect(this, TQ_SIGNAL(play()),
+            m_rgGUIApp, TQ_SLOT(slotPlay()) );
+    connect(this, TQ_SIGNAL(stop()),
+            m_rgGUIApp, TQ_SLOT(slotStop()) );
+    connect(this, TQ_SIGNAL(record()),
+            m_rgGUIApp, TQ_SLOT(slotRecord()) );
+    connect(this, TQ_SIGNAL(rewind()),
+            m_rgGUIApp, TQ_SLOT(slotRewind()) );
+    connect(this, TQ_SIGNAL(rewindToBeginning()),
+            m_rgGUIApp, TQ_SLOT(slotRewindToBeginning()) );
+    connect(this, TQ_SIGNAL(fastForward()),
+            m_rgGUIApp, TQ_SLOT(slotFastforward()) );
+    connect(this, TQ_SIGNAL(fastForwardToEnd()),
+            m_rgGUIApp, TQ_SLOT(slotFastForwardToEnd()) );
+    connect(this, TQ_SIGNAL(toggleRecord()),
+            m_rgGUIApp, TQ_SLOT(slotToggleRecord()) );
+    connect(this, TQ_SIGNAL(trackDown()),
+            m_rgGUIApp, TQ_SLOT(slotTrackDown()) );
+    connect(this, TQ_SIGNAL(trackUp()),
+            m_rgGUIApp, TQ_SLOT(slotTrackUp()) );
+    connect(this, TQ_SIGNAL(trackMute()),
+            m_rgGUIApp, TQ_SLOT(slotToggleMutedCurrentTrack()) );
+    connect(this, TQ_SIGNAL(trackRecord()),
+            m_rgGUIApp, TQ_SLOT(slotToggleRecordCurrentTrack()) );
 }
 
 LircCommander::command LircCommander::commands[] =
