@@ -139,91 +139,91 @@ RosegardenGUIView::RosegardenGUIView(bool showTrackLabels,
                                     m_rulerScale, showTrackLabels, unitsPerPixel, this /*hbox*/);
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(editSegment(Segment*)),
-            TQT_SLOT(slotEditSegment(Segment*)));
+            TQ_SIGNAL(editSegment(Segment*)),
+            TQ_SLOT(slotEditSegment(Segment*)));
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(editSegmentNotation(Segment*)),
-            TQT_SLOT(slotEditSegmentNotation(Segment*)));
+            TQ_SIGNAL(editSegmentNotation(Segment*)),
+            TQ_SLOT(slotEditSegmentNotation(Segment*)));
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(editSegmentMatrix(Segment*)),
-            TQT_SLOT(slotEditSegmentMatrix(Segment*)));
+            TQ_SIGNAL(editSegmentMatrix(Segment*)),
+            TQ_SLOT(slotEditSegmentMatrix(Segment*)));
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(editSegmentAudio(Segment*)),
-            TQT_SLOT(slotEditSegmentAudio(Segment*)));
+            TQ_SIGNAL(editSegmentAudio(Segment*)),
+            TQ_SLOT(slotEditSegmentAudio(Segment*)));
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(audioSegmentAutoSplit(Segment*)),
-            TQT_SLOT(slotSegmentAutoSplit(Segment*)));
+            TQ_SIGNAL(audioSegmentAutoSplit(Segment*)),
+            TQ_SLOT(slotSegmentAutoSplit(Segment*)));
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(editSegmentEventList(Segment*)),
-            TQT_SLOT(slotEditSegmentEventList(Segment*)));
+            TQ_SIGNAL(editSegmentEventList(Segment*)),
+            TQ_SLOT(slotEditSegmentEventList(Segment*)));
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(editRepeat(Segment*, timeT)),
-            TQT_SLOT(slotEditRepeat(Segment*, timeT)));
+            TQ_SIGNAL(editRepeat(Segment*, timeT)),
+            TQ_SLOT(slotEditRepeat(Segment*, timeT)));
 
     connect(m_trackEditor->getSegmentCanvas(),
-            TQT_SIGNAL(setPointerPosition(timeT)),
-            doc, TQT_SLOT(slotSetPointerPosition(timeT)));
+            TQ_SIGNAL(setPointerPosition(timeT)),
+            doc, TQ_SLOT(slotSetPointerPosition(timeT)));
 
     connect(m_trackEditor,
-            TQT_SIGNAL(droppedDocument(TQString)),
+            TQ_SIGNAL(droppedDocument(TQString)),
             parent,
-            TQT_SLOT(slotOpenDroppedURL(TQString)));
+            TQ_SLOT(slotOpenDroppedURL(TQString)));
 
     connect(m_trackEditor,
-            TQT_SIGNAL(droppedAudio(TQString)),
+            TQ_SIGNAL(droppedAudio(TQString)),
             this,
-            TQT_SLOT(slotDroppedAudio(TQString)));
+            TQ_SLOT(slotDroppedAudio(TQString)));
 
     connect(m_trackEditor,
-            TQT_SIGNAL(droppedNewAudio(TQString)),
+            TQ_SIGNAL(droppedNewAudio(TQString)),
             this,
-            TQT_SLOT(slotDroppedNewAudio(TQString)));
+            TQ_SLOT(slotDroppedNewAudio(TQString)));
 
     connect(m_instrumentParameterBox,
-            TQT_SIGNAL(changeInstrumentLabel(InstrumentId, TQString)),
+            TQ_SIGNAL(changeInstrumentLabel(InstrumentId, TQString)),
             this,
-            TQT_SLOT(slotChangeInstrumentLabel(InstrumentId, TQString)));
+            TQ_SLOT(slotChangeInstrumentLabel(InstrumentId, TQString)));
 
     connect(m_instrumentParameterBox,
-            TQT_SIGNAL(changeInstrumentLabel(InstrumentId, TQString)),
+            TQ_SIGNAL(changeInstrumentLabel(InstrumentId, TQString)),
             m_trackParameterBox,
-            TQT_SLOT(slotInstrumentLabelChanged(InstrumentId, TQString)));
+            TQ_SLOT(slotInstrumentLabelChanged(InstrumentId, TQString)));
 
     connect(m_trackEditor->getTrackButtons(),
-            TQT_SIGNAL(nameChanged()),
+            TQ_SIGNAL(nameChanged()),
             m_trackParameterBox,
-            TQT_SLOT(slotSelectedTrackNameChanged()));
+            TQ_SLOT(slotSelectedTrackNameChanged()));
 
     connect(m_trackEditor->getTrackButtons(),
-            TQT_SIGNAL(instrumentSelected(int)),
+            TQ_SIGNAL(instrumentSelected(int)),
             m_trackParameterBox,
-            TQT_SLOT(slotUpdateControls(int)));
+            TQ_SLOT(slotUpdateControls(int)));
 
     connect(m_trackParameterBox,
-            TQT_SIGNAL(instrumentSelected(TrackId, int)),
+            TQ_SIGNAL(instrumentSelected(TrackId, int)),
             m_trackEditor->getTrackButtons(),
-            TQT_SLOT(slotTrackInstrumentSelection(TrackId, int)));
+            TQ_SLOT(slotTrackInstrumentSelection(TrackId, int)));
 
-    connect(this, TQT_SIGNAL(controllerDeviceEventReceived(MappedEvent *, const void *)),
-            this, TQT_SLOT(slotControllerDeviceEventReceived(MappedEvent *, const void *)));
+    connect(this, TQ_SIGNAL(controllerDeviceEventReceived(MappedEvent *, const void *)),
+            this, TQ_SLOT(slotControllerDeviceEventReceived(MappedEvent *, const void *)));
 
     if (doc) {
         /* signal no longer exists
-        	connect(doc, TQT_SIGNAL(recordingSegmentUpdated(Segment *,
+        	connect(doc, TQ_SIGNAL(recordingSegmentUpdated(Segment *,
         						    timeT)),
-        		this, TQT_SLOT(slotUpdateRecordingSegment(Segment *,
+        		this, TQ_SLOT(slotUpdateRecordingSegment(Segment *,
         						      timeT)));
         */
 
         TQObject::connect
-        (getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-         m_trackEditor->getSegmentCanvas(), TQT_SLOT(slotUpdateSegmentsDrawBuffer()));
+        (getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+         m_trackEditor->getSegmentCanvas(), TQ_SLOT(slotUpdateSegmentsDrawBuffer()));
     }
 }
 
@@ -455,77 +455,77 @@ RosegardenGUIView::createNotationView(std::vector<Segment *> segmentsToEdit)
     // For tempo changes (ugh -- it'd be nicer to make a tempo change
     // command that could interpret all this stuff from the dialog)
     //
-    connect(notationView, TQT_SIGNAL(changeTempo(timeT,
+    connect(notationView, TQ_SIGNAL(changeTempo(timeT,
                                  tempoT,
                                  tempoT,
                                  TempoDialog::TempoDialogAction)),
-            RosegardenGUIApp::self(), TQT_SLOT(slotChangeTempo(timeT,
+            RosegardenGUIApp::self(), TQ_SLOT(slotChangeTempo(timeT,
                                            tempoT,
                                            tempoT,
                                            TempoDialog::TempoDialogAction)));
 
 
-    connect(notationView, TQT_SIGNAL(windowActivated()),
-            this, TQT_SLOT(slotActiveMainWindowChanged()));
+    connect(notationView, TQ_SIGNAL(windowActivated()),
+            this, TQ_SLOT(slotActiveMainWindowChanged()));
 
-    connect(notationView, TQT_SIGNAL(selectTrack(int)),
-            this, TQT_SLOT(slotSelectTrackSegments(int)));
+    connect(notationView, TQ_SIGNAL(selectTrack(int)),
+            this, TQ_SLOT(slotSelectTrackSegments(int)));
 
-    connect(notationView, TQT_SIGNAL(play()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotPlay()));
-    connect(notationView, TQT_SIGNAL(stop()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotStop()));
-    connect(notationView, TQT_SIGNAL(fastForwardPlayback()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotFastforward()));
-    connect(notationView, TQT_SIGNAL(rewindPlayback()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotRewind()));
-    connect(notationView, TQT_SIGNAL(fastForwardPlaybackToEnd()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotFastForwardToEnd()));
-    connect(notationView, TQT_SIGNAL(rewindPlaybackToBeginning()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotRewindToBeginning()));
-    connect(notationView, TQT_SIGNAL(panic()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotPanic()));
+    connect(notationView, TQ_SIGNAL(play()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotPlay()));
+    connect(notationView, TQ_SIGNAL(stop()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotStop()));
+    connect(notationView, TQ_SIGNAL(fastForwardPlayback()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotFastforward()));
+    connect(notationView, TQ_SIGNAL(rewindPlayback()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotRewind()));
+    connect(notationView, TQ_SIGNAL(fastForwardPlaybackToEnd()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotFastForwardToEnd()));
+    connect(notationView, TQ_SIGNAL(rewindPlaybackToBeginning()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotRewindToBeginning()));
+    connect(notationView, TQ_SIGNAL(panic()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotPanic()));
 
-    connect(notationView, TQT_SIGNAL(saveFile()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotFileSave()));
-    connect(notationView, TQT_SIGNAL(jumpPlaybackTo(timeT)),
-            getDocument(), TQT_SLOT(slotSetPointerPosition(timeT)));
-    connect(notationView, TQT_SIGNAL(openInNotation(std::vector<Segment *>)),
-            this, TQT_SLOT(slotEditSegmentsNotation(std::vector<Segment *>)));
-    connect(notationView, TQT_SIGNAL(openInMatrix(std::vector<Segment *>)),
-            this, TQT_SLOT(slotEditSegmentsMatrix(std::vector<Segment *>)));
-    connect(notationView, TQT_SIGNAL(openInPercussionMatrix(std::vector<Segment *>)),
-            this, TQT_SLOT(slotEditSegmentsPercussionMatrix(std::vector<Segment *>)));
-    connect(notationView, TQT_SIGNAL(openInEventList(std::vector<Segment *>)),
-            this, TQT_SLOT(slotEditSegmentsEventList(std::vector<Segment *>)));
+    connect(notationView, TQ_SIGNAL(saveFile()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotFileSave()));
+    connect(notationView, TQ_SIGNAL(jumpPlaybackTo(timeT)),
+            getDocument(), TQ_SLOT(slotSetPointerPosition(timeT)));
+    connect(notationView, TQ_SIGNAL(openInNotation(std::vector<Segment *>)),
+            this, TQ_SLOT(slotEditSegmentsNotation(std::vector<Segment *>)));
+    connect(notationView, TQ_SIGNAL(openInMatrix(std::vector<Segment *>)),
+            this, TQ_SLOT(slotEditSegmentsMatrix(std::vector<Segment *>)));
+    connect(notationView, TQ_SIGNAL(openInPercussionMatrix(std::vector<Segment *>)),
+            this, TQ_SLOT(slotEditSegmentsPercussionMatrix(std::vector<Segment *>)));
+    connect(notationView, TQ_SIGNAL(openInEventList(std::vector<Segment *>)),
+            this, TQ_SLOT(slotEditSegmentsEventList(std::vector<Segment *>)));
 /* hjj: WHAT DO DO WITH THIS ?
-    connect(notationView, TQT_SIGNAL(editMetadata(TQString)),
-            this, TQT_SLOT(slotEditMetadata(TQString)));
+    connect(notationView, TQ_SIGNAL(editMetadata(TQString)),
+            this, TQ_SLOT(slotEditMetadata(TQString)));
 */
-    connect(notationView, TQT_SIGNAL(editTriggerSegment(int)),
-            this, TQT_SLOT(slotEditTriggerSegment(int)));
-    connect(notationView, TQT_SIGNAL(staffLabelChanged(TrackId, TQString)),
-            this, TQT_SLOT(slotChangeTrackLabel(TrackId, TQString)));
-    connect(notationView, TQT_SIGNAL(toggleSolo(bool)),
-            RosegardenGUIApp::self(), TQT_SLOT(slotToggleSolo(bool)));
-    connect(notationView, TQT_SIGNAL(editTimeSignature(timeT)),
-            RosegardenGUIApp::self(), TQT_SLOT(slotEditTempos(timeT)));
+    connect(notationView, TQ_SIGNAL(editTriggerSegment(int)),
+            this, TQ_SLOT(slotEditTriggerSegment(int)));
+    connect(notationView, TQ_SIGNAL(staffLabelChanged(TrackId, TQString)),
+            this, TQ_SLOT(slotChangeTrackLabel(TrackId, TQString)));
+    connect(notationView, TQ_SIGNAL(toggleSolo(bool)),
+            RosegardenGUIApp::self(), TQ_SLOT(slotToggleSolo(bool)));
+    connect(notationView, TQ_SIGNAL(editTimeSignature(timeT)),
+            RosegardenGUIApp::self(), TQ_SLOT(slotEditTempos(timeT)));
 
     SequenceManager *sM = getDocument()->getSequenceManager();
 
-    connect(sM, TQT_SIGNAL(insertableNoteOnReceived(int, int)),
-            notationView, TQT_SLOT(slotInsertableNoteOnReceived(int, int)));
-    connect(sM, TQT_SIGNAL(insertableNoteOffReceived(int, int)),
-            notationView, TQT_SLOT(slotInsertableNoteOffReceived(int, int)));
+    connect(sM, TQ_SIGNAL(insertableNoteOnReceived(int, int)),
+            notationView, TQ_SLOT(slotInsertableNoteOnReceived(int, int)));
+    connect(sM, TQ_SIGNAL(insertableNoteOffReceived(int, int)),
+            notationView, TQ_SLOT(slotInsertableNoteOffReceived(int, int)));
 
-    connect(notationView, TQT_SIGNAL(stepByStepTargetRequested(TQObject *)),
-            this, TQT_SIGNAL(stepByStepTargetRequested(TQObject *)));
-    connect(this, TQT_SIGNAL(stepByStepTargetRequested(TQObject *)),
-            notationView, TQT_SLOT(slotStepByStepTargetRequested(TQObject *)));
-    connect(RosegardenGUIApp::self(), TQT_SIGNAL(compositionStateUpdate()),
-            notationView, TQT_SLOT(slotCompositionStateUpdate()));
-    connect(this, TQT_SIGNAL(compositionStateUpdate()),
-            notationView, TQT_SLOT(slotCompositionStateUpdate()));
+    connect(notationView, TQ_SIGNAL(stepByStepTargetRequested(TQObject *)),
+            this, TQ_SIGNAL(stepByStepTargetRequested(TQObject *)));
+    connect(this, TQ_SIGNAL(stepByStepTargetRequested(TQObject *)),
+            notationView, TQ_SLOT(slotStepByStepTargetRequested(TQObject *)));
+    connect(RosegardenGUIApp::self(), TQ_SIGNAL(compositionStateUpdate()),
+            notationView, TQ_SLOT(slotCompositionStateUpdate()));
+    connect(this, TQ_SIGNAL(compositionStateUpdate()),
+            notationView, TQ_SLOT(slotCompositionStateUpdate()));
 
     // Encourage the notation view window to open to the same
     // interval as the current segment view
@@ -657,73 +657,73 @@ RosegardenGUIView::createMatrixView(std::vector<Segment *> segmentsToEdit, bool
     // For tempo changes (ugh -- it'd be nicer to make a tempo change
     // command that could interpret all this stuff from the dialog)
     //
-    connect(matrixView, TQT_SIGNAL(changeTempo(timeT,
+    connect(matrixView, TQ_SIGNAL(changeTempo(timeT,
                                            tempoT,
                                            tempoT,
                                            TempoDialog::TempoDialogAction)),
-            RosegardenGUIApp::self(), TQT_SLOT(slotChangeTempo(timeT,
+            RosegardenGUIApp::self(), TQ_SLOT(slotChangeTempo(timeT,
                                            tempoT,
                                            tempoT,
                                            TempoDialog::TempoDialogAction)));
 
-    connect(matrixView, TQT_SIGNAL(windowActivated()),
-            this, TQT_SLOT(slotActiveMainWindowChanged()));
+    connect(matrixView, TQ_SIGNAL(windowActivated()),
+            this, TQ_SLOT(slotActiveMainWindowChanged()));
 
-    connect(matrixView, TQT_SIGNAL(selectTrack(int)),
-            this, TQT_SLOT(slotSelectTrackSegments(int)));
+    connect(matrixView, TQ_SIGNAL(selectTrack(int)),
+            this, TQ_SLOT(slotSelectTrackSegments(int)));
 
-    connect(matrixView, TQT_SIGNAL(play()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotPlay()));
-    connect(matrixView, TQT_SIGNAL(stop()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotStop()));
-    connect(matrixView, TQT_SIGNAL(fastForwardPlayback()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotFastforward()));
-    connect(matrixView, TQT_SIGNAL(rewindPlayback()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotRewind()));
-    connect(matrixView, TQT_SIGNAL(fastForwardPlaybackToEnd()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotFastForwardToEnd()));
-    connect(matrixView, TQT_SIGNAL(rewindPlaybackToBeginning()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotRewindToBeginning()));
-    connect(matrixView, TQT_SIGNAL(panic()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotPanic()));
+    connect(matrixView, TQ_SIGNAL(play()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotPlay()));
+    connect(matrixView, TQ_SIGNAL(stop()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotStop()));
+    connect(matrixView, TQ_SIGNAL(fastForwardPlayback()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotFastforward()));
+    connect(matrixView, TQ_SIGNAL(rewindPlayback()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotRewind()));
+    connect(matrixView, TQ_SIGNAL(fastForwardPlaybackToEnd()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotFastForwardToEnd()));
+    connect(matrixView, TQ_SIGNAL(rewindPlaybackToBeginning()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotRewindToBeginning()));
+    connect(matrixView, TQ_SIGNAL(panic()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotPanic()));
 
-    connect(matrixView, TQT_SIGNAL(saveFile()),
-            RosegardenGUIApp::self(), TQT_SLOT(slotFileSave()));
-    connect(matrixView, TQT_SIGNAL(jumpPlaybackTo(timeT)),
-            getDocument(), TQT_SLOT(slotSetPointerPosition(timeT)));
-    connect(matrixView, TQT_SIGNAL(openInNotation(std::vector<Segment *>)),
-            this, TQT_SLOT(slotEditSegmentsNotation(std::vector<Segment *>)));
-    connect(matrixView, TQT_SIGNAL(openInMatrix(std::vector<Segment *>)),
-            this, TQT_SLOT(slotEditSegmentsMatrix(std::vector<Segment *>)));
-    connect(matrixView, TQT_SIGNAL(openInEventList(std::vector<Segment *>)),
-            this, TQT_SLOT(slotEditSegmentsEventList(std::vector<Segment *>)));
-    connect(matrixView, TQT_SIGNAL(editTriggerSegment(int)),
-            this, TQT_SLOT(slotEditTriggerSegment(int)));
-    connect(matrixView, TQT_SIGNAL(toggleSolo(bool)),
-            RosegardenGUIApp::self(), TQT_SLOT(slotToggleSolo(bool)));
-    connect(matrixView, TQT_SIGNAL(editTimeSignature(timeT)),
-            RosegardenGUIApp::self(), TQT_SLOT(slotEditTempos(timeT)));
+    connect(matrixView, TQ_SIGNAL(saveFile()),
+            RosegardenGUIApp::self(), TQ_SLOT(slotFileSave()));
+    connect(matrixView, TQ_SIGNAL(jumpPlaybackTo(timeT)),
+            getDocument(), TQ_SLOT(slotSetPointerPosition(timeT)));
+    connect(matrixView, TQ_SIGNAL(openInNotation(std::vector<Segment *>)),
+            this, TQ_SLOT(slotEditSegmentsNotation(std::vector<Segment *>)));
+    connect(matrixView, TQ_SIGNAL(openInMatrix(std::vector<Segment *>)),
+            this, TQ_SLOT(slotEditSegmentsMatrix(std::vector<Segment *>)));
+    connect(matrixView, TQ_SIGNAL(openInEventList(std::vector<Segment *>)),
+            this, TQ_SLOT(slotEditSegmentsEventList(std::vector<Segment *>)));
+    connect(matrixView, TQ_SIGNAL(editTriggerSegment(int)),
+            this, TQ_SLOT(slotEditTriggerSegment(int)));
+    connect(matrixView, TQ_SIGNAL(toggleSolo(bool)),
+            RosegardenGUIApp::self(), TQ_SLOT(slotToggleSolo(bool)));
+    connect(matrixView, TQ_SIGNAL(editTimeSignature(timeT)),
+            RosegardenGUIApp::self(), TQ_SLOT(slotEditTempos(timeT)));
 
     SequenceManager *sM = getDocument()->getSequenceManager();
 
-    connect(sM, TQT_SIGNAL(insertableNoteOnReceived(int, int)),
-            matrixView, TQT_SLOT(slotInsertableNoteOnReceived(int, int)));
-    connect(sM, TQT_SIGNAL(insertableNoteOffReceived(int, int)),
-            matrixView, TQT_SLOT(slotInsertableNoteOffReceived(int, int)));
+    connect(sM, TQ_SIGNAL(insertableNoteOnReceived(int, int)),
+            matrixView, TQ_SLOT(slotInsertableNoteOnReceived(int, int)));
+    connect(sM, TQ_SIGNAL(insertableNoteOffReceived(int, int)),
+            matrixView, TQ_SLOT(slotInsertableNoteOffReceived(int, int)));
 
-    connect(matrixView, TQT_SIGNAL(stepByStepTargetRequested(TQObject *)),
-            this, TQT_SIGNAL(stepByStepTargetRequested(TQObject *)));
-    connect(this, TQT_SIGNAL(stepByStepTargetRequested(TQObject *)),
-            matrixView, TQT_SLOT(slotStepByStepTargetRequested(TQObject *)));
-    connect(RosegardenGUIApp::self(), TQT_SIGNAL(compositionStateUpdate()),
-            matrixView, TQT_SLOT(slotCompositionStateUpdate()));
-    connect(this, TQT_SIGNAL(compositionStateUpdate()),
-            matrixView, TQT_SLOT(slotCompositionStateUpdate()));
+    connect(matrixView, TQ_SIGNAL(stepByStepTargetRequested(TQObject *)),
+            this, TQ_SIGNAL(stepByStepTargetRequested(TQObject *)));
+    connect(this, TQ_SIGNAL(stepByStepTargetRequested(TQObject *)),
+            matrixView, TQ_SLOT(slotStepByStepTargetRequested(TQObject *)));
+    connect(RosegardenGUIApp::self(), TQ_SIGNAL(compositionStateUpdate()),
+            matrixView, TQ_SLOT(slotCompositionStateUpdate()));
+    connect(this, TQ_SIGNAL(compositionStateUpdate()),
+            matrixView, TQ_SLOT(slotCompositionStateUpdate()));
     connect(this,
-            TQT_SIGNAL(instrumentLevelsChanged(InstrumentId,
+            TQ_SIGNAL(instrumentLevelsChanged(InstrumentId,
                                            const LevelInfo &)),
             matrixView,
-            TQT_SLOT(slotInstrumentLevelsChanged(InstrumentId,
+            TQ_SLOT(slotInstrumentLevelsChanged(InstrumentId,
                                              const LevelInfo &)));
 
     // Encourage the matrix view window to open to the same
@@ -1543,12 +1543,12 @@ RosegardenGUIView::slotDroppedNewAudio(TQString audioDesc)
 
     // Connect the progress dialog
     //
-    connect(&aFM, TQT_SIGNAL(setProgress(int)),
-            progressDlg.progressBar(), TQT_SLOT(setValue(int)));
-    connect(&aFM, TQT_SIGNAL(setOperationName(TQString)),
-            &progressDlg, TQT_SLOT(slotSetOperationName(TQString)));
-    connect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-            &aFM, TQT_SLOT(slotStopImport()));
+    connect(&aFM, TQ_SIGNAL(setProgress(int)),
+            progressDlg.progressBar(), TQ_SLOT(setValue(int)));
+    connect(&aFM, TQ_SIGNAL(setOperationName(TQString)),
+            &progressDlg, TQ_SLOT(slotSetOperationName(TQString)));
+    connect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+            &aFM, TQ_SLOT(slotStopImport()));
 
     try {
         audioFileId = aFM.importURL(kurl, sampleRate);
@@ -1564,10 +1564,10 @@ RosegardenGUIView::slotDroppedNewAudio(TQString audioDesc)
         return ;
     }
              
-    disconnect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-               &aFM, TQT_SLOT(slotStopImport()));
-    connect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-            &aFM, TQT_SLOT(slotStopPreview()));
+    disconnect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+               &aFM, TQ_SLOT(slotStopImport()));
+    connect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+            &aFM, TQ_SLOT(slotStopPreview()));
     progressDlg.progressBar()->show();
     progressDlg.slotSetOperationName(i18n("Generating audio preview..."));
 
@@ -1581,8 +1581,8 @@ RosegardenGUIView::slotDroppedNewAudio(TQString audioDesc)
         //return false;
     }
 
-    disconnect(&progressDlg, TQT_SIGNAL(cancelClicked()),
-               &aFM, TQT_SLOT(slotStopPreview()));
+    disconnect(&progressDlg, TQ_SIGNAL(cancelClicked()),
+               &aFM, TQ_SLOT(slotStopPreview()));
 
     // add the file at the sequencer
     emit addAudioFile(audioFileId);
@@ -1747,8 +1747,8 @@ RosegardenGUIView::slotUpdateRecordingSegment(Segment *segment,
 
     /* signal no longer exists
         TQObject::connect
-    	(getDocument(), TQT_SIGNAL(recordingSegmentUpdated(Segment *, timeT)),
-    	 view, TQT_SLOT(slotUpdateRecordingSegment(Segment *, timeT)));
+    	(getDocument(), TQ_SIGNAL(recordingSegmentUpdated(Segment *, timeT)),
+    	 view, TQ_SLOT(slotUpdateRecordingSegment(Segment *, timeT)));
     */
 
     view->show();
@@ -1998,31 +1998,31 @@ RosegardenGUIView::createEventView(std::vector<Segment *> segmentsToEdit)
                                          segmentsToEdit,
                                          this);
 
-    connect(eventView, TQT_SIGNAL(windowActivated()),
-        this, TQT_SLOT(slotActiveMainWindowChanged()));
+    connect(eventView, TQ_SIGNAL(windowActivated()),
+        this, TQ_SLOT(slotActiveMainWindowChanged()));
 
-    connect(eventView, TQT_SIGNAL(selectTrack(int)),
-            this, TQT_SLOT(slotSelectTrackSegments(int)));
+    connect(eventView, TQ_SIGNAL(selectTrack(int)),
+            this, TQ_SLOT(slotSelectTrackSegments(int)));
 
-    connect(eventView, TQT_SIGNAL(saveFile()),
-        RosegardenGUIApp::self(), TQT_SLOT(slotFileSave()));
+    connect(eventView, TQ_SIGNAL(saveFile()),
+        RosegardenGUIApp::self(), TQ_SLOT(slotFileSave()));
 
-    connect(eventView, TQT_SIGNAL(openInNotation(std::vector<Segment *>)),
-        this, TQT_SLOT(slotEditSegmentsNotation(std::vector<Segment *>)));
-    connect(eventView, TQT_SIGNAL(openInMatrix(std::vector<Segment *>)),
-        this, TQT_SLOT(slotEditSegmentsMatrix(std::vector<Segment *>)));
-    connect(eventView, TQT_SIGNAL(openInPercussionMatrix(std::vector<Segment *>)),
-        this, TQT_SLOT(slotEditSegmentsPercussionMatrix(std::vector<Segment *>)));
-    connect(eventView, TQT_SIGNAL(openInEventList(std::vector<Segment *>)),
-        this, TQT_SLOT(slotEditSegmentsEventList(std::vector<Segment *>)));
-    connect(eventView, TQT_SIGNAL(editTriggerSegment(int)),
-        this, TQT_SLOT(slotEditTriggerSegment(int)));
-    connect(this, TQT_SIGNAL(compositionStateUpdate()),
-        eventView, TQT_SLOT(slotCompositionStateUpdate()));
-    connect(RosegardenGUIApp::self(), TQT_SIGNAL(compositionStateUpdate()),
-        eventView, TQT_SLOT(slotCompositionStateUpdate()));
-    connect(eventView, TQT_SIGNAL(toggleSolo(bool)),
-            RosegardenGUIApp::self(), TQT_SLOT(slotToggleSolo(bool)));
+    connect(eventView, TQ_SIGNAL(openInNotation(std::vector<Segment *>)),
+        this, TQ_SLOT(slotEditSegmentsNotation(std::vector<Segment *>)));
+    connect(eventView, TQ_SIGNAL(openInMatrix(std::vector<Segment *>)),
+        this, TQ_SLOT(slotEditSegmentsMatrix(std::vector<Segment *>)));
+    connect(eventView, TQ_SIGNAL(openInPercussionMatrix(std::vector<Segment *>)),
+        this, TQ_SLOT(slotEditSegmentsPercussionMatrix(std::vector<Segment *>)));
+    connect(eventView, TQ_SIGNAL(openInEventList(std::vector<Segment *>)),
+        this, TQ_SLOT(slotEditSegmentsEventList(std::vector<Segment *>)));
+    connect(eventView, TQ_SIGNAL(editTriggerSegment(int)),
+        this, TQ_SLOT(slotEditTriggerSegment(int)));
+    connect(this, TQ_SIGNAL(compositionStateUpdate()),
+        eventView, TQ_SLOT(slotCompositionStateUpdate()));
+    connect(RosegardenGUIApp::self(), TQ_SIGNAL(compositionStateUpdate()),
+        eventView, TQ_SLOT(slotCompositionStateUpdate()));
+    connect(eventView, TQ_SIGNAL(toggleSolo(bool)),
+            RosegardenGUIApp::self(), TQ_SLOT(slotToggleSolo(bool)));
 
     // create keyboard accelerators on view
     //
