@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -84,8 +82,8 @@ AudioPropertiesPage::AudioPropertiesPage(RosegardenGUIDoc *doc,
 
     calculateStats();
 
-    connect(m_changePathButton, TQT_SIGNAL(released()),
-            TQT_SLOT(slotFileDialog()));
+    connect(m_changePathButton, TQ_SIGNAL(released()),
+            TQ_SLOT(slotFileDialog()));
 
     addTab(frame, i18n("Modify audio path"));
 }
@@ -97,9 +95,9 @@ AudioPropertiesPage::calculateStats()
     //
     TQString mountPoint = TDEIO::findPathMountPoint(m_path->text());
     KDiskFreeSp * job = new KDiskFreeSp;
-    connect(job, TQT_SIGNAL(foundMountPoint(const TQString&, unsigned long, unsigned long,
+    connect(job, TQ_SIGNAL(foundMountPoint(const TQString&, unsigned long, unsigned long,
                                         unsigned long)),
-            this, TQT_SLOT(slotFoundMountPoint(const TQString&, unsigned long, unsigned long,
+            this, TQ_SLOT(slotFoundMountPoint(const TQString&, unsigned long, unsigned long,
                                            unsigned long)));
     job->readDF(mountPoint);
 }
@@ -155,11 +153,11 @@ AudioPropertiesPage::slotFileDialog()
                               this, "file dialog", true);
     fileDialog->setMode(KFile::Directory);
 
-    connect(fileDialog, TQT_SIGNAL(fileSelected(const TQString&)),
-            TQT_SLOT(slotFileSelected(const TQString&)));
+    connect(fileDialog, TQ_SIGNAL(fileSelected(const TQString&)),
+            TQ_SLOT(slotFileSelected(const TQString&)));
 
-    connect(fileDialog, TQT_SIGNAL(destroyed()),
-            TQT_SLOT(slotDirectoryDialogClosed()));
+    connect(fileDialog, TQ_SIGNAL(destroyed()),
+            TQ_SLOT(slotDirectoryDialogClosed()));
 
     if (fileDialog->exec() == TQDialog::Accepted) {
         m_path->setText(fileDialog->selectedFile());
