@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -446,14 +444,14 @@ NotationConfigurationPage::NotationConfigurationPage(TDEConfig *cfg,
     m_viewButton = new TQPushButton(i18n("View"), frame);
     layout->addMultiCellWidget(m_font, row, row, 1, 2);
     layout->addWidget(m_viewButton, row, 3);
-    TQObject::connect(m_viewButton, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(slotViewButtonPressed()));
+    TQObject::connect(m_viewButton, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(slotViewButtonPressed()));
 #else
     layout->addMultiCellWidget(m_font, row, row, 1, 3);
 #endif
     m_font->setEditable(false);
-    TQObject::connect(m_font, TQT_SIGNAL(activated(int)),
-                     this, TQT_SLOT(slotFontComboChanged(int)));
+    TQObject::connect(m_font, TQ_SIGNAL(activated(int)),
+                     this, TQ_SLOT(slotFontComboChanged(int)));
     ++row;
 
     TQFrame *subFrame = new TQFrame(frame);
