@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -36,7 +34,7 @@ namespace Rosegarden
 
 class AddTracksDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
