@@ -52,7 +52,7 @@
 #include "sound/WAVAudioFile.h"
 #include "UnusedAudioSelectionDialog.h"
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tdeaction.h>
 #include <kcommand.h>
 #include <tdefiledialog.h>
