@@ -37,7 +37,7 @@ namespace Rosegarden
 
 class InterpretDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     InterpretDialog(TQWidget *parent);
