@@ -41,8 +41,8 @@ PitchDialog::PitchDialog(TQWidget *parent, TQString title, int defaultPitch) :
     m_pitchChooser = new PitchChooser(title, vbox, defaultPitch);
 
     setButtonText(User1, i18n("Reset"));
-    connect(this, TQT_SIGNAL(user1Clicked()),
-            m_pitchChooser, TQT_SLOT(slotResetToDefault()));
+    connect(this, TQ_SIGNAL(user1Clicked()),
+            m_pitchChooser, TQ_SLOT(slotResetToDefault()));
 }
 
 int
