@@ -35,7 +35,7 @@ namespace Rosegarden
 
 class PitchPickerDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
