@@ -40,7 +40,7 @@ class RosegardenGUIDoc;
 
 class SplitByRecordingSrcDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     SplitByRecordingSrcDialog(TQWidget *parent, RosegardenGUIDoc *doc);
