@@ -61,11 +61,11 @@ TextEventDialog::TextEventDialog(TQWidget *parent,
     TQVBox *vbox = makeVBoxMainWidget();
 
     TQGroupBox *entryBox = new TQGroupBox
-                          (1, Qt::Horizontal, i18n("Specification"), vbox);
+                          (1, TQt::Horizontal, i18n("Specification"), vbox);
     TQGroupBox *exampleBox = new TQGroupBox
-                            (1, Qt::Horizontal, i18n("Preview"), vbox);
+                            (1, TQt::Horizontal, i18n("Preview"), vbox);
 
-    TQGrid *entryGrid = new TQGrid(2, Qt::Horizontal, entryBox);
+    TQGrid *entryGrid = new TQGrid(2, TQt::Horizontal, entryBox);
 
     new TQLabel(i18n("Text:  "), entryGrid);
     m_text = new TQLineEdit(entryGrid);
@@ -327,23 +327,23 @@ TextEventDialog::TextEventDialog(TQWidget *parent,
     m_prevLyric = config->readEntry("previous_lyric", "");
     m_prevAnnotation = config->readEntry("previous_annotation", "");
 
-    TQObject::connect(m_text, TQT_SIGNAL(textChanged(const TQString &)),
-                     this, TQT_SLOT(slotTextChanged(const TQString &)));
-    TQObject::connect(m_typeCombo, TQT_SIGNAL(activated(const TQString &)),
-                     this, TQT_SLOT(slotTypeChanged(const TQString &)));
-    TQObject::connect(this, TQT_SIGNAL(okClicked()), this, TQT_SLOT(slotOK()));
-    TQObject::connect(m_dynamicShortcutCombo, TQT_SIGNAL(activated(const TQString &)),
-                     this, TQT_SLOT(slotDynamicShortcutChanged(const TQString &)));
-    TQObject::connect(m_directionShortcutCombo, TQT_SIGNAL(activated(const TQString &)),
-                     this, TQT_SLOT(slotDirectionShortcutChanged(const TQString &)));
-    TQObject::connect(m_localDirectionShortcutCombo, TQT_SIGNAL(activated(const TQString &)),
-                     this, TQT_SLOT(slotLocalDirectionShortcutChanged(const TQString &)));
-    TQObject::connect(m_tempoShortcutCombo, TQT_SIGNAL(activated(const TQString &)),
-                     this, TQT_SLOT(slotTempoShortcutChanged(const TQString &)));
-    TQObject::connect(m_localTempoShortcutCombo, TQT_SIGNAL(activated(const TQString &)),
-                     this, TQT_SLOT(slotLocalTempoShortcutChanged(const TQString &)));
-    TQObject::connect(m_lilyPondDirectiveCombo, TQT_SIGNAL(activated(const TQString &)),
-                     this, TQT_SLOT(slotLilyPondDirectiveChanged(const TQString &)));
+    TQObject::connect(m_text, TQ_SIGNAL(textChanged(const TQString &)),
+                     this, TQ_SLOT(slotTextChanged(const TQString &)));
+    TQObject::connect(m_typeCombo, TQ_SIGNAL(activated(const TQString &)),
+                     this, TQ_SLOT(slotTypeChanged(const TQString &)));
+    TQObject::connect(this, TQ_SIGNAL(okClicked()), this, TQ_SLOT(slotOK()));
+    TQObject::connect(m_dynamicShortcutCombo, TQ_SIGNAL(activated(const TQString &)),
+                     this, TQ_SLOT(slotDynamicShortcutChanged(const TQString &)));
+    TQObject::connect(m_directionShortcutCombo, TQ_SIGNAL(activated(const TQString &)),
+                     this, TQ_SLOT(slotDirectionShortcutChanged(const TQString &)));
+    TQObject::connect(m_localDirectionShortcutCombo, TQ_SIGNAL(activated(const TQString &)),
+                     this, TQ_SLOT(slotLocalDirectionShortcutChanged(const TQString &)));
+    TQObject::connect(m_tempoShortcutCombo, TQ_SIGNAL(activated(const TQString &)),
+                     this, TQ_SLOT(slotTempoShortcutChanged(const TQString &)));
+    TQObject::connect(m_localTempoShortcutCombo, TQ_SIGNAL(activated(const TQString &)),
+                     this, TQ_SLOT(slotLocalTempoShortcutChanged(const TQString &)));
+    TQObject::connect(m_lilyPondDirectiveCombo, TQ_SIGNAL(activated(const TQString &)),
+                     this, TQ_SLOT(slotLilyPondDirectiveChanged(const TQString &)));
 
     m_text->setFocus();
     slotTypeChanged(strtoqstr(getTextType()));
