@@ -24,7 +24,7 @@
 #include "TransportDialog.h"
 
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include "base/Composition.h"
 #include "base/NotationTypes.h"
 #include "base/RealTime.h"
@@ -211,7 +211,7 @@ TransportDialog::TransportDialog(TQWidget *parent,
 
     TQFont localFont(m_transport->OutDisplay->font() );
     localFont.setFamily( "lucida" );
-    localFont.setBold( TRUE );
+    localFont.setBold( true );
 
     m_transport->TempoDisplay->setFont( localFont );
     m_transport->TimeSigDisplay->setFont( localFont );
@@ -470,7 +470,7 @@ TransportDialog::displayTime()
         break;
 
     case BarMetronomeMode:
-        m_clearMetronomeTimer->start(1700, FALSE);
+        m_clearMetronomeTimer->start(1700, false);
         m_transport->TimeDisplayLabel->setText("MET"); // DO NOT i18n
         m_transport->TimeDisplayLabel->show();
         break;
