@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -41,7 +39,7 @@ class FingeringBox;
 
 class GuitarChordEditorDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
