@@ -24,7 +24,7 @@
 #include "MatrixResizer.h"
 
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include "base/Event.h"
 #include "base/Segment.h"
 #include "base/Selection.h"
