@@ -38,7 +38,7 @@ class MatrixStaff;
 
 class MatrixToolBox : public EditToolBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     MatrixToolBox(MatrixView* parent);
