@@ -78,7 +78,7 @@ class LevelInfo;
  */
 class MatrixView : public EditView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     friend class MatrixSelector;
@@ -666,12 +666,12 @@ protected:
 };
 
 // Commented this out - was a MatrixView inner class, but we get a warning
-// that Q_OBJECT can't be used in an inner class - gl
+// that TQ_OBJECT can't be used in an inner class - gl
 //
 
 // class NoteSender : public TQObject
 // {
-//     Q_OBJECT
+//     TQ_OBJECT
 //     
         
 // public:
