@@ -256,7 +256,7 @@ void PianoKeyboard::mouseMoveEvent(TQMouseEvent* e)
         }
     }
 
-    if (e->state() & Qt::LeftButton) {
+    if (e->state() & TQt::LeftButton) {
         if (m_selecting)
             emit keySelected(e->y(), true);
         else
@@ -272,7 +272,7 @@ void PianoKeyboard::mousePressEvent(TQMouseEvent *e)
 {
     TQt::ButtonState bs = e->state();
 
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == TQt::LeftButton) {
         m_mouseDown = true;
         m_selecting = (bs & TQt::ShiftButton);
         m_lastKeyPressed = e->y();
@@ -286,7 +286,7 @@ void PianoKeyboard::mousePressEvent(TQMouseEvent *e)
 
 void PianoKeyboard::mouseReleaseEvent(TQMouseEvent *e)
 {
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == TQt::LeftButton) {
         m_mouseDown = false;
         m_selecting = false;
         emit keyReleased(e->y(), false);
