@@ -1,6 +1,3 @@
-
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -46,7 +43,7 @@ class NotationView;
  */
 class NotationEraser : public NotationTool
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     friend class NotationToolBox;
