@@ -78,7 +78,7 @@ NoteFont::NoteFont(std::string fontName, int size) :
 
     if (m_blankPixmap == 0) {
         m_blankPixmap = new TQPixmap(10, 10);
-        m_blankPixmap->setMask(TQBitmap(10, 10, TRUE));
+        m_blankPixmap->setMask(TQBitmap(10, 10, true));
     }
 
     // Locate our font's pixmap map in the font map, create if necessary
