@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -63,7 +61,7 @@ namespace Rosegarden
 MIDIInstrumentParameterPanel::MIDIInstrumentParameterPanel(RosegardenGUIDoc *doc, TQWidget* parent):
         InstrumentParameterPanel(doc, parent),
         m_rotaryFrame(0),
-        m_rotaryMapper(new TQSignalMapper(TQT_TQOBJECT(this)))
+        m_rotaryMapper(new TQSignalMapper(this))
 {
     m_mainGrid = new TQGridLayout(this, 10, 3, 2, 1);
 
@@ -152,32 +150,32 @@ MIDIInstrumentParameterPanel::MIDIInstrumentParameterPanel(RosegardenGUIDoc *doc
 
     // Connect up the toggle boxes
     //
-    connect(m_percussionCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotTogglePercussion(bool)));
+    connect(m_percussionCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotTogglePercussion(bool)));
 
-    connect(m_programCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotToggleProgramChange(bool)));
+    connect(m_programCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotToggleProgramChange(bool)));
 
-    connect(m_bankCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotToggleBank(bool)));
+    connect(m_bankCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotToggleBank(bool)));
 
-    connect(m_variationCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotToggleVariation(bool)));
+    connect(m_variationCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotToggleVariation(bool)));
 
 
     // Connect activations
     //
-    connect(m_bankValue, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotSelectBank(int)));
+    connect(m_bankValue, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotSelectBank(int)));
 
-    connect(m_variationValue, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotSelectVariation(int)));
+    connect(m_variationValue, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotSelectVariation(int)));
 
-    connect(m_programValue, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotSelectProgram(int)));
+    connect(m_programValue, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotSelectProgram(int)));
 
-    connect(m_channelValue, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotSelectChannel(int)));
+    connect(m_channelValue, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotSelectChannel(int)));
 
     // don't select any of the options in any dropdown
     m_programValue->setCurrentItem( -1);
@@ -185,8 +183,8 @@ MIDIInstrumentParameterPanel::MIDIInstrumentParameterPanel(RosegardenGUIDoc *doc
     m_channelValue->setCurrentItem( -1);
     m_variationValue->setCurrentItem( -1);
 
-    connect(m_rotaryMapper, TQT_SIGNAL(mapped(int)),
-            this, TQT_SLOT(slotControllerChanged(int)));
+    connect(m_rotaryMapper, TQ_SIGNAL(mapped(int)),
+            this, TQ_SLOT(slotControllerChanged(int)));
 }
 
 void
@@ -417,15 +415,15 @@ MIDIInstrumentParameterPanel::setupControllers(MidiDevice *md)
 
             // Connect
             //
-            connect(rotary, TQT_SIGNAL(valueChanged(float)),
-                    m_rotaryMapper, TQT_SLOT(map()));
+            connect(rotary, TQ_SIGNAL(valueChanged(float)),
+                    m_rotaryMapper, TQ_SLOT(map()));
 
             rmi = m_rotaries.end();
         }
 
         // Add signal mapping
         //
-        m_rotaryMapper->setMapping(TQT_TQOBJECT(rotary),
+        m_rotaryMapper->setMapping(rotary,
                                    int(it->getControllerValue()));
 
         count++;
