@@ -46,8 +46,8 @@ BaseTool* BaseToolBox::getTool(const TQString& toolName)
 
     if (!tool) tool = createTool(toolName);
 
-    connect(tool, TQT_SIGNAL(showContextHelp(const TQString &)),
-            this, TQT_SIGNAL(showContextHelp(const TQString &)));
+    connect(tool, TQ_SIGNAL(showContextHelp(const TQString &)),
+            this, TQ_SIGNAL(showContextHelp(const TQString &)));
     
     return tool;
 }
