@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -34,7 +32,7 @@
 #include "base/Exception.h"
 #include "CategoryElement.h"
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tdeglobal.h>
 #include <tqfile.h>
 #include <tqfileinfo.h>
