@@ -28,7 +28,7 @@
 
 class TDEStartupLogo : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
