@@ -86,8 +86,8 @@ ControlRuler::ControlRuler(Segment *segment,
 
     setFixedHeight(sizeHint().height());
 
-    connect(this, TQT_SIGNAL(stateChange(const TQString&, bool)),
-            m_parentEditView, TQT_SLOT(slotStateChanged(const TQString&, bool)));
+    connect(this, TQ_SIGNAL(stateChange(const TQString&, bool)),
+            m_parentEditView, TQ_SLOT(slotStateChanged(const TQString&, bool)));
 
     m_numberFloat = new TextFloat(this);
     m_numberFloat->hide();
@@ -162,7 +162,7 @@ ControlRuler::segmentDeleted(const Segment *)
 
 void ControlRuler::contentsMousePressEvent(TQMouseEvent* e)
 {
-    if (e->button() != Qt::LeftButton) {
+    if (e->button() != TQt::LeftButton) {
         m_numberFloat->hide();
         m_selecting = false;
         return ;
@@ -243,7 +243,7 @@ void ControlRuler::contentsMousePressEvent(TQMouseEvent* e)
 
 void ControlRuler::contentsMouseReleaseEvent(TQMouseEvent* e)
 {
-    if (e->button() != Qt::LeftButton) {
+    if (e->button() != TQt::LeftButton) {
         m_numberFloat->hide();
         m_selecting = false;
         return ;
