@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -26,7 +24,7 @@
 #include "ControlBlockMmapper.h"
 #include "misc/Debug.h"
 
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include "misc/Strings.h"
 #include "base/Composition.h"
 #include "base/Exception.h"
