@@ -53,7 +53,7 @@
 #include "sound/MappedEvent.h"
 #include "sound/MappedStudio.h"
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tdeaction.h>
 #include <tdeglobal.h>
 #include <tdemainwindow.h>
