@@ -26,7 +26,7 @@
 #include <tdeapplication.h>
 
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "base/Device.h"
