@@ -70,14 +70,14 @@ MidiMixerWindow::MidiMixerWindow(TQWidget *parent,
     //
     setupTabs();
 
-    KStdAction::close(TQT_TQOBJECT(this),
-                      TQT_SLOT(slotClose()),
+    KStdAction::close(this,
+                      TQ_SLOT(slotClose()),
                       actionCollection());
 
     TQIconSet icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                              ("transport-play")));
-    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
-                TQT_SIGNAL(play()), actionCollection(), "play");
+    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, this,
+                TQ_SIGNAL(play()), actionCollection(), "play");
     // Alternative shortcut for Play
     TDEShortcut playShortcut = play->shortcut();
     playShortcut.append( KKey(Key_Return + CTRL) );
@@ -85,43 +85,43 @@ MidiMixerWindow::MidiMixerWindow(TQWidget *parent,
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-stop")));
-    new TDEAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
-                TQT_SIGNAL(stop()), actionCollection(), "stop");
+    new TDEAction(i18n("&Stop"), icon, Key_Insert, this,
+                TQ_SIGNAL(stop()), actionCollection(), "stop");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind")));
-    new TDEAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
-                TQT_SIGNAL(rewindPlayback()), actionCollection(),
+    new TDEAction(i18n("Re&wind"), icon, Key_End, this,
+                TQ_SIGNAL(rewindPlayback()), actionCollection(),
                 "playback_pointer_back_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd")));
-    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
-                TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
+    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, this,
+                TQ_SIGNAL(fastForwardPlayback()), actionCollection(),
                 "playback_pointer_forward_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind-end")));
-    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
+    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, this,
+                TQ_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
                 "playback_pointer_start");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd-end")));
-    new TDEAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
+    new TDEAction(i18n("Fast Forward to &End"), icon, 0, this,
+                TQ_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
                 "playback_pointer_end");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-record")));
-    new TDEAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(record()), actionCollection(),
+    new TDEAction(i18n("&Record"), icon, 0, this,
+                TQ_SIGNAL(record()), actionCollection(),
                 "record");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-panic")));
-    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
-                TQT_SIGNAL(panic()), actionCollection(),
+    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, this,
+                TQ_SIGNAL(panic()), actionCollection(),
                 "panic");
 
     createGUI("midimixer.rc");
@@ -144,8 +144,8 @@ MidiMixerWindow::setupTabs()
     //
     m_tabWidget = new TQTabWidget(this);
     setCentralWidget(m_tabWidget);
-    connect(m_tabWidget, TQT_SIGNAL(currentChanged(TQWidget *)),
-            this, TQT_SLOT(slotCurrentTabChanged(TQWidget *)));
+    connect(m_tabWidget, TQ_SIGNAL(currentChanged(TQWidget *)),
+            this, TQ_SLOT(slotCurrentTabChanged(TQWidget *)));
     m_tabWidget->setTabPosition(TQTabWidget::Bottom);
     setCaption(i18n("MIDI Mixer"));
 
@@ -246,8 +246,8 @@ MidiMixerWindow::setupTabs()
 
                     controller->setKnobColour(knobColour);
 
-                    connect(controller, TQT_SIGNAL(valueChanged(float)),
-                            this, TQT_SLOT(slotControllerChanged(float)));
+                    connect(controller, TQ_SIGNAL(valueChanged(float)),
+                            this, TQ_SLOT(slotControllerChanged(float)));
 
                     mainLayout->addWidget(controller, i + 1, posCount,
                                           TQt::AlignCenter);
@@ -291,8 +291,8 @@ MidiMixerWindow::setupTabs()
 
                 // Connect them up
                 //
-                connect(fader, TQT_SIGNAL(faderChanged(float)),
-                        this, TQT_SLOT(slotFaderLevelChanged(float)));
+                connect(fader, TQ_SIGNAL(faderChanged(float)),
+                        this, TQ_SLOT(slotFaderLevelChanged(float)));
 
                 // Update all the faders and controllers
                 //
@@ -321,11 +321,11 @@ MidiMixerWindow::addTab(TQWidget *tab, const TQString &title)
 void
 MidiMixerWindow::slotFaderLevelChanged(float value)
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
 
     for (FaderVector::const_iterator it = m_faders.begin();
             it != m_faders.end(); ++it) {
-        if (TQT_BASE_OBJECT((*it)->m_volumeFader) == TQT_BASE_OBJECT_CONST(s)) {
+        if ((*it)->m_volumeFader == s) {
             Instrument *instr = m_studio->
                                 getInstrumentById((*it)->m_id);
 
@@ -374,12 +374,12 @@ MidiMixerWindow::slotFaderLevelChanged(float value)
 void
 MidiMixerWindow::slotControllerChanged(float value)
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
     unsigned int i = 0, j = 0;
 
     for (i = 0; i < m_faders.size(); ++i) {
         for (j = 0; j < m_faders[i]->m_controllerRotaries.size(); ++j) {
-            if (TQT_BASE_OBJECT(m_faders[i]->m_controllerRotaries[j].second) == TQT_BASE_OBJECT_CONST(s))
+            if (m_faders[i]->m_controllerRotaries[j].second == s)
                 break;
         }
 
