@@ -35,7 +35,7 @@
 #include <tdeglobal.h>
 #include <klineedit.h>
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tqcheckbox.h>
 #include <tqcursor.h>
 #include <tqfile.h>
