@@ -25,7 +25,7 @@
 #include <tqlayout.h>
 
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include "misc/Debug.h"
 #include "AudioRouteMenu.h"
 #include "AudioVUMeter.h"
