@@ -30,7 +30,7 @@ namespace Rosegarden {
 class BigArrowButton : public KArrowButton
 {
 public:
-    BigArrowButton(TQWidget *parent = 0, Qt::ArrowType arrow = Qt::UpArrow,
+    BigArrowButton(TQWidget *parent = 0, TQt::ArrowType arrow = TQt::UpArrow,
                    const char *name = 0) :
         KArrowButton(parent, arrow, name) { }
     virtual ~BigArrowButton() { } 
