@@ -33,7 +33,7 @@ namespace Rosegarden
 QDeferScrollView::QDeferScrollView(TQWidget* parent, const char *name, WFlags f)
         : TQScrollView(parent, name, f)
 {
-    setFocusPolicy(TQ_WheelFocus);
+    setFocusPolicy(TQWidget::WheelFocus);
 }
 
 void QDeferScrollView::setBottomMargin(int m)
